#include <glade/glade.h>
#ifdef HILDON
#  include <hildon-widgets/hildon-program.h>

HildonWindow *hildonwindow;
#elif HILDON_CHINOOK
#  include <hildon/hildon-program.h>

HildonWindow *hildonwindow;
#endif

GladeXML *glade;
